Plugin types
============

Misc plugins
------------

TODO

VCS plugins
-----------

TODO

Renderer plugins
----------------

TODO

README plugins
^^^^^^^^^^^^^^

TODO

Target plugins
^^^^^^^^^^^^^^

TODO

TODO

Action plugins
--------------

TODO

Multiprocessing, GIL, etc.

Command plugins
^^^^^^^^^^^^^^^

TODO For very simple example, see the Make plugin. For a bit more complex example, see the autocommand plugin.
